@@ -11,6 +11,7 @@ import random
 import socket
 from termcolor import colored
 from collections import defaultdict
+import pylogstash
 
 from dqueue import from_uri
 from dqueue.core import Queue, Task
@@ -19,6 +20,7 @@ from dqueue.proxy import QueueProxy
 import dqueue.core as core 
 
 logger = logging.getLogger()
+log_stasher = pylogstash.LogStasher(sep="/")
 
 @click.group()
 @click.option("-q", "--quiet", default=False, is_flag=True)
@@ -153,7 +155,7 @@ def list(obj, debug, log, info, select, json_output):
             print("")
 
         if debug:
-            print(pprint.pformat(task))
+            print(json.dumps(task, indent=4,sort_keys=True))
             t = Task.from_task_dict(task['task_dict'])
             print("Task: ", t)
             print("Task key: ", t.key)
@@ -370,9 +372,28 @@ def guardian(obj, watch):
         # stats
 
         print("getting queue statistics...")
+        print(">>", obj['queue'].get_summary())
         log_info(obj['queue'])
         print("\n")
 
+        log_stasher.log(
+                    dict(
+                        origin="oda-node",
+                        action="queue-status",
+                        summary=obj['queue'].summary,
+                    )
+                )
+        
+        for k,v in obj['queue'].summary.items():
+            log_stasher.log(
+                         { 
+                            "origin": "oda-node",
+                            "action": "queue-status-per-kind",
+                            "oda-node/queue/kind": k,
+                            "oda-node/queue/njobs": v,
+                        } 
+                    )
+
         print("sleeping", watch)
 
         if not watch:
@@ -484,13 +505,13 @@ def ask(obj, target, module, assume):
     task_data = dict(
                 object_identity=dict(
                     assumptions=[
-                            ['ii_spectra_exract', {'request_root_node': True}]
+                            [target, {'request_root_node': True}]
                         ] + [['', a] for a in assume],
                     expected_hashe='None',
                     factory_name=target,
                     full_name=target,
                     modules=[
-                            ['git', m[len("git://"):].split("/")[0], m[len("git://"):].split("/")[1]]
+                            ['git', m[len("git://"):].split("/")[0], m]
                             for m in module
                         ]
                 )
@@ -504,6 +525,9 @@ def ask(obj, target, module, assume):
                 ),
             )
 
+    #print("odahub responds", r)
+    print(f"\033[31m{r['state']:10s}\033[0m \033[33m{r['modified']}\033[0m \033[34m{r['created']}\033[0m")
+
 
 def main():
     cli(obj={})
