@@ -17,7 +17,7 @@ from functools import reduce
 
 from bravado.client import SwaggerClient
 
-__version__ = "0.1.43"
+__version__ = "0.1.45"
 
 try:
     import io
@@ -113,6 +113,18 @@ class Task:
             pid=os.getpid(),
         )
     
+    @property
+    def n_times_failed(self):
+        if self.execution_info is None:
+            return 0
+        return self.execution_info.get('n_times_failed', 0)
+ 
+    def note_failure(self):
+        if self.execution_info is None:
+            logger.warning("no execution info: not noting failure")
+        else:
+            self.execution_info['n_times_failed'] = self.n_times_failed + 1
+    
     @property
     def as_dict(self):
         return dict(
@@ -158,6 +170,7 @@ class Task:
         self=cls(task_dict['task_data'])
         self.depends_on=task_dict.get('depends_on', [])
         self.submission_info=task_dict['submission_info']
+        self.execution_info=task_dict['execution_info']
 
         return self
 
@@ -1020,10 +1033,13 @@ class Queue:
 
         history = [model_to_dict(en) for en in EventLog.select().where(EventLog.task_key == task.key).order_by(EventLog.id.desc()).execute(database=None)]
         n_failed = len([he for he in history if he['task_state'] == "failed"])
+        
+        self.log_task(f"event logs reports failed {n_failed}, task record shows {self.current_task.n_times_failed}", task, "failed")
+
+        n_failed = max(n_failed, self.current_task.n_times_failed)
 
-        self.log_task("task failed %i times already"%n_failed,task,"failed")
         if n_failed < n_failed_retries:
-            self.log_task("task failure forgiven, to waiting",task,"waiting")
+            self.log_task("task failure forgiven, to waiting", task, "waiting")
             #time.sleep( (5+2**int(n_failed/2))*sleep_multiplier )
             r=TaskEntry.update({
                         TaskEntry.state: "waiting",
@@ -1044,9 +1060,11 @@ class Queue:
     def task_failed(self,update=lambda x:None):
         update(self.current_task)
 
-        task= self.current_task
+        task = self.current_task
 
-        self.log_task("task failed",self.current_task,"failed")
+        task.note_failure()
+
+        self.log_task(f"task failed: {self.current_task.n_times_failed} times",self.current_task,"failed")
 
         r=TaskEntry.update({
                     TaskEntry.state: "failed",
@@ -1064,14 +1082,24 @@ class Queue:
                 log("removing",fromk + "/" + key)
                 TaskEntry.delete().where(TaskEntry.key==key).execute(database=None)
 
-    @property
-    def summary(self):
+    def get_summary(self, since_days=None):
         r={}
         for kind in "waiting","running","done","failed","locked", "corrupt":
-            r[kind] = TaskEntry.select().where(TaskEntry.state==kind, TaskEntry.queue==self.queue).count()
+            if since_days is not None:
+                r[kind] = TaskEntry.select().where(
+                                                TaskEntry.state==kind, 
+                                                TaskEntry.queue==self.queue, 
+                                                TaskEntry.modified >= datetime.datetime.now() - datetime.timedelta(days=float(since_days))
+                                             ).count()
+            else:
+                r[kind] = TaskEntry.select().where(TaskEntry.state==kind, TaskEntry.queue==self.queue).count()
            # .execute(database=None)
             #
         return r
+
+    @property
+    def summary(self):
+        return self.get_summary()
         
     @property
     def info(self):
